==> haskell-persistent-qq-2.12.0.7-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-qq
version:              2.12.0.7
visibility:           public
id:                   persistent-qq-2.12.0.7-K8EUTTTa8WXCfs741yATJA
key:                  persistent-qq-2.12.0.7-K8EUTTTa8WXCfs741yATJA
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
homepage:             https://github.com/yesodweb/persistent#readme
synopsis:             Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  b5cf3fad0eb4d818e9de287a617f0dea
exposed:              True
exposed-modules:      Database.Persist.Sql.Raw.QQ
hidden-modules:       Paths_persistent_qq
import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-qq
hs-libraries:         HSpersistent-qq-2.12.0.7-K8EUTTTa8WXCfs741yATJA
depends:
    base-4.17.2.1 haskell-src-meta-0.8.15-5WiMp1jO1CNBevtjEwe0V8
    mtl-2.2.2 persistent-2.14.5.2-8Hz6E7aiM9AHDtqaIt9CpM
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock

haddock-html:         /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-qq-2.12.0.7-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-qq
version:              2.12.0.7
visibility:           public
id:                   persistent-qq-2.12.0.7-5hcymrgbFTbLACx8VWjhfE
key:                  persistent-qq-2.12.0.7-5hcymrgbFTbLACx8VWjhfE
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
homepage:             https://github.com/yesodweb/persistent#readme
synopsis:             Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  9390bab7f458c5fb3bcb5f7d6379b9e0
exposed:              True
exposed-modules:      Database.Persist.Sql.Raw.QQ
hidden-modules:       Paths_persistent_qq
import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-qq
hs-libraries:         HSpersistent-qq-2.12.0.7-5hcymrgbFTbLACx8VWjhfE
depends:
    base-4.17.2.1 haskell-src-meta-0.8.15-HatmekmiFtC6upShQVUnU8
    mtl-2.2.2 persistent-2.14.5.2-JnliJ8BwA5X6Fk41m8RdUG
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock

haddock-html:         /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
